# PyCaching

## Please note that this project is in Beta and may not be suitable for stable, production code. 

A small utility for doing filesystem caching. Works as a stand-alone class that can be interacted with or a simple decorator on functions

Works really well for network fetched data, especially if you do a lot of runs or tests!